You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ws.apache.org by ve...@apache.org on 2015/10/11 22:33:39 UTC

svn commit: r1708023 - in /webservices/axiom/trunk: aspects/core-aspects/src/main/java/org/apache/axiom/core/ aspects/om-aspects/src/main/java/org/apache/axiom/soap/impl/common/ testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/om/element/ test...

Author: veithen
Date: Sun Oct 11 20:33:38 2015
New Revision: 1708023

URL: http://svn.apache.org/viewvc?rev=1708023&view=rev
Log:
Some Javadoc fixes.

Modified:
    webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/AttributeMatcher.java
    webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/CoreChildNode.java
    webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/CoreElement.java
    webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/CoreParentNode.java
    webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/ElementMatcher.java
    webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/NSAwareAttributeMatcher.java
    webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/NodeIterator.java
    webservices/axiom/trunk/aspects/om-aspects/src/main/java/org/apache/axiom/soap/impl/common/Checker.java
    webservices/axiom/trunk/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/om/element/TestAddAttributeWithMaskedNamespaceDeclaration.java
    webservices/axiom/trunk/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/om/element/TestGetSAXSourceIdentityTransformOnFragment.java
    webservices/axiom/trunk/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/omdom/OMDOMTestSuiteBuilder.java

Modified: webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/AttributeMatcher.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/AttributeMatcher.java?rev=1708023&r1=1708022&r2=1708023&view=diff
==============================================================================
--- webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/AttributeMatcher.java (original)
+++ webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/AttributeMatcher.java Sun Oct 11 20:33:38 2015
@@ -29,7 +29,7 @@ public interface AttributeMatcher {
      * {@link CoreElement#coreSetAttribute(AttributeMatcher, String, String, String, String)}, or
      * they are determined by the return values of {@link #getNamespaceURI(CoreAttribute)} and
      * {@link #getName(CoreAttribute)} if
-     * {@link CoreElement#coreSetAttribute(AttributeMatcher, CoreAttribute, NodeMigrationPolicy, boolean, CoreDocument, com.googlecode.ddom.core.CoreElement.ReturnValue)}
+     * {@link CoreElement#coreSetAttribute(AttributeMatcher, CoreAttribute, DetachPolicy)}
      * is used. It is
      * not required that these parameters strictly represent the namespace URI and local name of the
      * attribute. Their exact meaning is defined by the particular {@link AttributeMatcher}
@@ -47,7 +47,7 @@ public interface AttributeMatcher {
 
     /**
      * Get the <tt>namespaceURI</tt> parameter for an existing attribute. This method is used by
-     * {@link CoreElement#coreSetAttribute(AttributeMatcher, CoreAttribute, NodeMigrationPolicy, boolean, CoreDocument, com.googlecode.ddom.core.CoreElement.ReturnValue)}
+     * {@link CoreElement#coreSetAttribute(AttributeMatcher, CoreAttribute, DetachPolicy)}
      * which passes its return value as parameter to {@link #matches(CoreAttribute, String, String)}.
      * 
      * @param attr the attribute
@@ -57,7 +57,7 @@ public interface AttributeMatcher {
     
     /**
      * Get the <tt>name</tt> parameter for an existing attribute. This method is used by
-     * {@link CoreElement#coreSetAttribute(AttributeMatcher, CoreAttribute, NodeMigrationPolicy, boolean, CoreDocument, com.googlecode.ddom.core.CoreElement.ReturnValue)}
+     * {@link CoreElement#coreSetAttribute(AttributeMatcher, CoreAttribute, DetachPolicy)}
      * which passes its return value as parameter to {@link #matches(CoreAttribute, String, String)}.
      * 
      * @param attr the attribute
@@ -95,7 +95,6 @@ public interface AttributeMatcher {
      *            see above
      * @param value
      *            see above
-     * @throws DeferredParsingException
      */
     void update(CoreAttribute attr, String prefix, String value);
 }

Modified: webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/CoreChildNode.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/CoreChildNode.java?rev=1708023&r1=1708022&r2=1708023&view=diff
==============================================================================
--- webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/CoreElement.java (original)
+++ webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/CoreElement.java Sun Oct 11 20:33:38 2015
@@ -59,18 +59,18 @@ public interface CoreElement extends Cor
      * @param namespaceURI
      *            the <code>namespaceURI</code> parameter to pass to
      *            {@link AttributeMatcher#matches(CoreAttribute, String, String)} and
-     *            {@link AttributeMatcher#createAttribute(NodeFactory, CoreDocument, String, String, String, String)}
+     *            {@link AttributeMatcher#createAttribute(CoreElement, String, String, String, String)}
      * @param name
      *            the <code>name</code> parameter to pass to
      *            {@link AttributeMatcher#matches(CoreAttribute, String, String)} and
-     *            {@link AttributeMatcher#createAttribute(NodeFactory, CoreDocument, String, String, String, String)}
+     *            {@link AttributeMatcher#createAttribute(CoreElement, String, String, String, String)}
      * @param prefix
      *            the <code>prefix</code> parameter to pass to
-     *            {@link AttributeMatcher#createAttribute(NodeFactory, CoreDocument, String, String, String, String)}
+     *            {@link AttributeMatcher#createAttribute(CoreElement, String, String, String, String)}
      *            and {@link AttributeMatcher#update(CoreAttribute, String, String)}
      * @param value
      *            the <code>value</code> parameter to pass to
-     *            {@link AttributeMatcher#createAttribute(NodeFactory, CoreDocument, String, String, String, String)}
+     *            {@link AttributeMatcher#createAttribute(CoreElement, String, String, String, String)}
      *            and {@link AttributeMatcher#update(CoreAttribute, String, String)}
      */
     void coreSetAttribute(AttributeMatcher matcher, String namespaceURI, String name, String prefix, String value);

Modified: webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/CoreParentNode.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/CoreParentNode.java?rev=1708023&r1=1708022&r2=1708023&view=diff
==============================================================================
--- webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/CoreParentNode.java (original)
+++ webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/CoreParentNode.java Sun Oct 11 20:33:38 2015
@@ -34,4 +34,6 @@ public interface CoreParentNode extends
     int getState();
     void coreSetState(int state);
     void build();
+
+    <T extends CoreElement> NodeIterator<T> coreGetElements(Axis axis, Class<T> type, ElementMatcher<? super T> matcher, String namespaceURI, String name, ExceptionTranslator exceptionTranslator, DetachPolicy detachPolicy);
 }

Modified: webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/ElementMatcher.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/ElementMatcher.java?rev=1708023&r1=1708022&r2=1708023&view=diff
==============================================================================
--- webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/ElementMatcher.java (original)
+++ webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/ElementMatcher.java Sun Oct 11 20:33:38 2015
@@ -101,7 +101,7 @@ public interface ElementMatcher<T extend
     /**
      * Check if the given element matches. The values of the <code>namespaceURI</code> and
      * <code>name</code> parameters are those passed to
-     * {@link CoreParentNode#coreGetElements(Axis, Class, ElementMatcher, String, String)}.
+     * {@link CoreParentNode#coreGetElements(Axis, Class, ElementMatcher, String, String, ExceptionTranslator, DetachPolicy)}.
      * 
      * @param element
      *            the element to check

Modified: webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/NSAwareAttributeMatcher.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/NSAwareAttributeMatcher.java?rev=1708023&r1=1708022&r2=1708023&view=diff
==============================================================================
--- webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/NSAwareAttributeMatcher.java (original)
+++ webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/NSAwareAttributeMatcher.java Sun Oct 11 20:33:38 2015
@@ -31,9 +31,9 @@ package org.apache.axiom.core;
  * <dt><code>prefix</code>
  * <dd>The prefix to be used when creating a new attribute or updating an existing one.
  * </dl>
- * If the namespace URI is the emtpy string, then this class will also match namespace unaware
+ * If the namespace URI is the empty string, then this class will also match namespace unaware
  * attributes. Note that the class doesn't match namespace declarations (for which
- * {@link AttributeMatcher#NAMESPACE_DECLARATION} can be used).
+ * {@link NamespaceDeclarationMatcher} can be used).
  */
 public final class NSAwareAttributeMatcher implements AttributeMatcher {
     private final DetachPolicy detachPolicy;
@@ -52,8 +52,8 @@ public final class NSAwareAttributeMatch
      * @param updatePrefix
      *            Specifies if the prefix of an existing attribute should be updated (based on the
      *            value of the <code>prefix</code> parameter. If this is <code>false</code>, then
-     *            <code>prefix</prefix> is only used when creating new attributes and prefixes of
-     * existing attributes are preserved (i.e. only their value is updated).
+     *            <code>prefix</code> is only used when creating new attributes and prefixes of
+     *            existing attributes are preserved (i.e. only their value is updated).
      */
     public NSAwareAttributeMatcher(DetachPolicy detachPolicy, boolean matchNSUnawareAttributes,
             boolean updatePrefix) {

Modified: webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/NodeIterator.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/NodeIterator.java?rev=1708023&r1=1708022&r2=1708023&view=diff
==============================================================================
--- webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/NodeIterator.java (original)
+++ webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/NodeIterator.java Sun Oct 11 20:33:38 2015
@@ -32,7 +32,7 @@ import java.util.Iterator;
  * allowed to throw {@link UnsupportedOperationException}.
  * <li>A {@link ConcurrentModificationException} MUST be thrown when the iterator is used after the
  * last node returned by {@link Iterator#next()} has been removed using a method other than
- * {@link Iterator#remove()} (e.g. {@link CoreChildNode#coreDetach()}).
+ * {@link Iterator#remove()} (e.g. {@link CoreChildNode#coreDetach(DetachPolicy)}).
  * <li>If a {@link CoreModelException} occurs inside {@link Iterator#hasNext()},
  * {@link Iterator#next()} or {@link Iterator#remove()}, then the implementation MUST use the
  * supplied {@link ExceptionTranslator} to translate that checked exception into an unchecked

Modified: webservices/axiom/trunk/aspects/om-aspects/src/main/java/org/apache/axiom/soap/impl/common/Checker.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/aspects/om-aspects/src/main/java/org/apache/axiom/soap/impl/common/Checker.java?rev=1708023&r1=1708022&r2=1708023&view=diff
==============================================================================
--- webservices/axiom/trunk/aspects/om-aspects/src/main/java/org/apache/axiom/soap/impl/common/Checker.java (original)
+++ webservices/axiom/trunk/aspects/om-aspects/src/main/java/org/apache/axiom/soap/impl/common/Checker.java Sun Oct 11 20:33:38 2015
@@ -23,7 +23,7 @@ import org.apache.axiom.soap.SOAPHeaderB
 /**
  * A local interface we can use to make "header checker" objects which can be used by
  * HeaderIterators to filter results.  This really SHOULD be done with anonymous classes:
- * <p/>
+ * <pre>
  * public void getHeadersByRole(final String role) {
  *     return new HeaderIterator() {
  *         public boolean checkHeader(SOAPHeaderBlock header) {
@@ -32,8 +32,7 @@ import org.apache.axiom.soap.SOAPHeaderB
  *             return false;
  *         }
  *     }
- * }
- * <p/>
+ * }</pre>
  * ...but there appears to be some kind of weird problem with the JVM not correctly scoping the
  * passed "role" value in a situation like the above.  As such, we have to make Checker objects
  * instead (sigh).

Modified: webservices/axiom/trunk/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/om/element/TestAddAttributeWithMaskedNamespaceDeclaration.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/om/element/TestAddAttributeWithMaskedNamespaceDeclaration.java?rev=1708023&r1=1708022&r2=1708023&view=diff
==============================================================================
--- webservices/axiom/trunk/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/om/element/TestAddAttributeWithMaskedNamespaceDeclaration.java (original)
+++ webservices/axiom/trunk/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/om/element/TestAddAttributeWithMaskedNamespaceDeclaration.java Sun Oct 11 20:33:38 2015
@@ -34,15 +34,15 @@ import org.apache.axiom.ts.dimension.Add
  * new namespace declaration if an equivalent namespace declaration exists but is masked.
  * The test attempts to create the following XML:
  * <pre>
- * &lt;a xmlns:p="urn:ns1">
- *   &lt;b xmlns:p="urn:ns2">
- *     &lt;c xmlns:p="urn:ns1" p:attr="test"/>
- *   &lt;/b>
- * &lt;/a></pre>
- * It only explicitly creates the namespace declarations on <tt>&lt;a></tt> and
- * <tt>&lt;b></tt>. When adding the attribute to <tt>&lt;c></tt>, Axiom must generate
- * a new namespace declaration because the declaration on <tt>&lt;a></tt> is masked
- * by the one on <tt>&lt;b></tt>.
+ * &lt;a xmlns:p="urn:ns1"&gt;
+ *   &lt;b xmlns:p="urn:ns2"&gt;
+ *     &lt;c xmlns:p="urn:ns1" p:attr="test"/&gt;
+ *   &lt;/b&gt;
+ * &lt;/a&gt;</pre>
+ * It only explicitly creates the namespace declarations on <tt>&lt;a&gt;</tt> and
+ * <tt>&lt;b&gt;</tt>. When adding the attribute to <tt>&lt;c&gt;</tt>, Axiom must generate
+ * a new namespace declaration because the declaration on <tt>&lt;a&gt;</tt> is masked
+ * by the one on <tt>&lt;b&gt;</tt>.
  * <p>
  * Note that because of WSTX-202, Axiom will not be able to serialize the resulting XML.
  */

Modified: webservices/axiom/trunk/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/om/element/TestGetSAXSourceIdentityTransformOnFragment.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/om/element/TestGetSAXSourceIdentityTransformOnFragment.java?rev=1708023&r1=1708022&r2=1708023&view=diff
==============================================================================
--- webservices/axiom/trunk/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/om/element/TestGetSAXSourceIdentityTransformOnFragment.java (original)
+++ webservices/axiom/trunk/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/om/element/TestGetSAXSourceIdentityTransformOnFragment.java Sun Oct 11 20:33:38 2015
@@ -47,7 +47,7 @@ import org.xml.sax.ContentHandler;
  *   descendant elements or attributes (but may be used in the value of an attribute).</li>   
  * </ol>
  * Example:
- * <pre>&lt;root xmlns:ns="urn:ns">&lt;element attr="ns:someThing"/>&lt;root></pre>
+ * <pre>&lt;root xmlns:ns="urn:ns"&gt;&lt;element attr="ns:someThing"/&gt;&lt;root&gt;</pre>
  * In that case, when constructing an {@link SAXSource} from the child element, the namespace
  * mapping for the <tt>ns</tt> prefix should be visible to the consumer. Otherwise it would not
  * be able to interpret the attribute value correctly. This is relevant e.g. when validating

Modified: webservices/axiom/trunk/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/omdom/OMDOMTestSuiteBuilder.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/omdom/OMDOMTestSuiteBuilder.java?rev=1708023&r1=1708022&r2=1708023&view=diff
==============================================================================
--- webservices/axiom/trunk/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/omdom/OMDOMTestSuiteBuilder.java (original)
+++ webservices/axiom/trunk/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/omdom/OMDOMTestSuiteBuilder.java Sun Oct 11 20:33:38 2015
@@ -24,8 +24,7 @@ import org.apache.axiom.testutils.suite.
 /**
  * Builds a test suite for Axiom implementations that also implement DOM. Note that this test suite
  * only contains tests that depend on Axiom specific features. Pure DOM tests (that are executable
- * with a standard DOM implementation) should go to
- * {@link org.apache.axiom.ts.dom.DOMTestSuiteBuilder}.
+ * with a standard DOM implementation) should go to <code>dom-testsuite</code>.
  */
 public class OMDOMTestSuiteBuilder extends MatrixTestSuiteBuilder {
     private final DOMMetaFactory metaFactory;
--- webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/CoreChildNode.java (original)
+++ webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/CoreChildNode.java Sun Oct 11 20:33:38 2015
@@ -27,18 +27,20 @@ public interface CoreChildNode extends C
      */
     CoreElement coreGetParentElement();
 
+    CoreChildNode coreGetNextSibling();
+
     /**
      * Get the next sibling if it is available. The sibling is available if it is complete or
      * if the builder has started building the node. In the latter case,
      * {@link OMNode#isComplete()} may return <code>false</code> when called on the sibling. 
      * In contrast to {@link OMNode#getNextOMSibling()}, this method will never modify
      * the state of the underlying parser.
      * 
-     * @return the next sibling or <code>null</code> if the node has no next sibling or
-     *         the builder has not yet started to build the next sibling
+     * @return the next sibling or <code>null</code> if the node has no next sibling or the builder
+     *         has not yet started to build the next sibling
      */
     CoreChildNode coreGetNextSiblingIfAvailable();
 
+    void coreDetach(DetachPolicy detachPolicy);
+
     /**
      * Clone this node according to the provided policy.
      * 
@@ -27,18 +27,20 @@ public interface CoreChildNode extends C
     /**
-     * Get the next sibling if it is available. The sibling is available if it is complete or
-     * if the builder has started building the node. In the latter case,
-     * {@link OMNode#isComplete()} may return <code>false</code> when called on the sibling. 
-     * In contrast to {@link OMNode#getNextOMSibling()}, this method will never modify
-     * the state of the underlying parser.
+     * Get the next sibling if it is available. The sibling is available if it is complete or if the
+     * builder has started building the node. In contrast to {@link #coreGetNextSibling()}, this
+     * method will never modify the state of the underlying parser.
      * 

Modified: webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/CoreElement.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/aspects/core-aspects/src/main/java/org/apache/axiom/core/CoreElement.java?rev=1708023&r1=1708022&r2=1708023&view=diff
==============================================================================